
**5. Technical Guide**
======================

Please refer to the following papers for more details on the Unit
Commitment (UC) Formulation using Mixed Integer Programming (MIP):


-  Chowdhury, A. F. M., Kern, J., Dang, T. D., & Galelli, S. (2020).
   `PowNet: A Network-Constrained Unit Commitment/Economic Dispatch Model
   for Large-Scale Power Systems Analysis <https://openresearchsoftware.metajnl.com/articles/10.5334/jors.302>`_. Journal of Open Research
   Software, 8(1).

..

-  Knueven, B., Ostrowski, J., & Watson, J. P. (2020). `On mixed-integer
   programming formulations for the unit commitment problem <https://pubsonline.informs.org/doi/10.1287/ijoc.2019.0944>`_. INFORMS
   Journal on Computing, 32(4), 857-876.

..

-  Hörsch, J., Ronellenfitsch, H., Witthaut, D., & Brown, T. (2018).
   `Linear optimal power flow using cycle flows <https://doi.org/10.1016/j.epsr.2017.12.034>`_. Electric Power Systems
   Research, 158, 126-135.
